# TableCellBorder

A border around a table cell. Table cell borders cannot be transparent. To hide a table cell border, make its width 0.

**Type:** object

## Properties

- **color** ([OptionalColor](optionalcolor.md)): The color of the border. This color cannot be transparent.
- **width** ([Dimension](dimension.md)): The width of the border.
- **dashStyle** (enum): The dash style of the border.
